@@ -1,10 +1,11 @@
 import a0
 import click
 import sys
+from . import _util
 
 
 @click.command()
-@click.argument("topic")
+@click.argument("topic", shell_complete=_util.autocomplete_topics("pubsub"))
 @click.argument("value")
 @click.option("--header", "-h", multiple=True)
 @click.option("--file", "-f", is_flag=True)
